@@ -32,4 +32,6 @@ call('git push --tags', shell=True)
 
 env = os.environ
 env['CONVERT_README'] = 'true'
-call('python setup.py sdist bdist_wheel upload', shell=True, env=env)
+call('rm -rf dist/*', shell=True, env=env)
+call('python setup.py sdist bdist_wheel', shell=True, env=env)
+call('twine upload dist/*', shell=True, env=env)
