@@ -1,6 +1,6 @@
 import pytest
 from thefuck.rules.cargo_no_command import match, get_new_command
-from tests.utils import Command
+from thefuck.types import Command
 
 
 no_such_subcommand_old = """No such subcommand
@@ -15,14 +15,14 @@ no_such_subcommand = """error: no such subcommand
 
 
 @pytest.mark.parametrize('command', [
-    Command(script='cargo buid', stderr=no_such_subcommand_old),
-    Command(script='cargo buils', stderr=no_such_subcommand)])
+    Command('cargo buid', no_such_subcommand_old),
+    Command('cargo buils', no_such_subcommand)])
 def test_match(command):
     assert match(command)
 
 
 @pytest.mark.parametrize('command, new_command', [
-    (Command('cargo buid', stderr=no_such_subcommand_old), 'cargo build'),
-    (Command('cargo buils', stderr=no_such_subcommand), 'cargo build')])
+    (Command('cargo buid', no_such_subcommand_old), 'cargo build'),
+    (Command('cargo buils', no_such_subcommand), 'cargo build')])
 def test_get_new_command(command, new_command):
     assert get_new_command(command) == new_command
