@@ -1,10 +1,9 @@
 import pytest
 from io import BytesIO
 from thefuck.rules.git_checkout import match, get_branches, get_new_command
-from tests.utils import Command
+from thefuck.types import Command
 
 
-@pytest.fixture
 def did_not_match(target, did_you_forget=False):
     error = ("error: pathspec '{}' did not match any "
              "file(s) known to git.".format(target))
@@ -21,17 +20,17 @@ def git_branch(mocker, branches):
 
 
 @pytest.mark.parametrize('command', [
-    Command(script='git checkout unknown', stderr=did_not_match('unknown')),
-    Command(script='git commit unknown', stderr=did_not_match('unknown'))])
+    Command('git checkout unknown', did_not_match('unknown')),
+    Command('git commit unknown', did_not_match('unknown'))])
 def test_match(command):
     assert match(command)
 
 
 @pytest.mark.parametrize('command', [
-    Command(script='git submodule update unknown',
-            stderr=did_not_match('unknown', True)),
-    Command(script='git checkout known', stderr=('')),
-    Command(script='git commit known', stderr=(''))])
+    Command('git submodule update unknown',
+            did_not_match('unknown', True)),
+    Command('git checkout known', ''),
+    Command('git commit known', '')])
 def test_not_match(command):
     assert not match(command)
 
@@ -40,6 +39,11 @@ def test_not_match(command):
     (b'', []),
     (b'* master', ['master']),
     (b'  remotes/origin/master', ['master']),
+    (b'  remotes/origin/test/1', ['test/1']),
+    (b'  remotes/origin/test/1/2/3', ['test/1/2/3']),
+    (b'  test/1', ['test/1']),
+    (b'  test/1/2/3', ['test/1/2/3']),
+    (b'  remotes/origin/HEAD -> origin/master', []),
     (b'  just-another-branch', ['just-another-branch']),
     (b'* master\n  just-another-branch', ['master', 'just-another-branch']),
     (b'* master\n  remotes/origin/master\n  just-another-branch',
@@ -51,19 +55,19 @@ def test_get_branches(branches, branch_list, git_branch):
 
 @pytest.mark.parametrize('branches, command, new_command', [
     (b'',
-     Command(script='git checkout unknown', stderr=did_not_match('unknown')),
-     'git branch unknown && git checkout unknown'),
+     Command('git checkout unknown', did_not_match('unknown')),
+     ['git checkout -b unknown']),
     (b'',
-     Command('git commit unknown', stderr=did_not_match('unknown')),
-     'git branch unknown && git commit unknown'),
+     Command('git commit unknown', did_not_match('unknown')),
+     ['git branch unknown && git commit unknown']),
     (b'  test-random-branch-123',
-     Command(script='git checkout tst-rdm-brnch-123',
-             stderr=did_not_match('tst-rdm-brnch-123')),
-     'git checkout test-random-branch-123'),
+     Command('git checkout tst-rdm-brnch-123',
+             did_not_match('tst-rdm-brnch-123')),
+     ['git checkout test-random-branch-123', 'git checkout -b tst-rdm-brnch-123']),
     (b'  test-random-branch-123',
-     Command(script='git commit tst-rdm-brnch-123',
-             stderr=did_not_match('tst-rdm-brnch-123')),
-     'git commit test-random-branch-123')])
+     Command('git commit tst-rdm-brnch-123',
+             did_not_match('tst-rdm-brnch-123')),
+     ['git commit test-random-branch-123'])])
 def test_get_new_command(branches, command, new_command, git_branch):
     git_branch(branches)
     assert get_new_command(command) == new_command
