@@ -1,10 +1,10 @@
 import pytest
 from thefuck.rules.git_rebase_no_changes import match, get_new_command
-from tests.utils import Command
+from thefuck.types import Command
 
 
 @pytest.fixture
-def stdout():
+def output():
     return '''Applying: Test commit
 No changes - did you forget to use 'git add'?
 If there is nothing left to stage, chances are that something else
@@ -17,12 +17,12 @@ To check out the original branch and stop rebasing, run "git rebase --abort".
 '''
 
 
-def test_match(stdout):
-    assert match(Command('git rebase --continue', stdout=stdout))
-    assert not match(Command('git rebase --continue'))
-    assert not match(Command('git rebase --skip'))
+def test_match(output):
+    assert match(Command('git rebase --continue', output))
+    assert not match(Command('git rebase --continue', ''))
+    assert not match(Command('git rebase --skip', ''))
 
 
-def test_get_new_command(stdout):
-    assert (get_new_command(Command('git rebase --continue', stdout=stdout)) ==
+def test_get_new_command(output):
+    assert (get_new_command(Command('git rebase --continue', output)) ==
             'git rebase --skip')
