@@ -1,6 +1,6 @@
 import pytest
 from thefuck.rules.history import match, get_new_command
-from tests.utils import Command
+from thefuck.types import Command
 
 
 @pytest.fixture(autouse=True)
@@ -12,16 +12,16 @@ def history_without_current(mocker):
 
 @pytest.mark.parametrize('script', ['ls cet', 'daff x'])
 def test_match(script):
-    assert match(Command(script=script))
+    assert match(Command(script, ''))
 
 
 @pytest.mark.parametrize('script', ['apt-get', 'nocommand y'])
 def test_not_match(script):
-    assert not match(Command(script=script))
+    assert not match(Command(script, ''))
 
 
 @pytest.mark.parametrize('script, result', [
     ('ls cet', 'ls cat'),
     ('daff x', 'diff x')])
 def test_get_new_command(script, result):
-    assert get_new_command(Command(script)) == result
+    assert get_new_command(Command(script, '')) == result
