@@ -1,42 +1,10 @@
 from imp import load_source
 import os
 import sys
-from pathlib import Path
+from warnings import warn
 from six import text_type
-
-
-ALL_ENABLED = object()
-DEFAULT_RULES = [ALL_ENABLED]
-DEFAULT_PRIORITY = 1000
-
-DEFAULT_SETTINGS = {'rules': DEFAULT_RULES,
-                    'exclude_rules': [],
-                    'wait_command': 3,
-                    'require_confirmation': True,
-                    'no_colors': False,
-                    'debug': False,
-                    'priority': {},
-                    'env': {'LC_ALL': 'C', 'LANG': 'C', 'GIT_TRACE': '1'}}
-
-ENV_TO_ATTR = {'THEFUCK_RULES': 'rules',
-               'THEFUCK_EXCLUDE_RULES': 'exclude_rules',
-               'THEFUCK_WAIT_COMMAND': 'wait_command',
-               'THEFUCK_REQUIRE_CONFIRMATION': 'require_confirmation',
-               'THEFUCK_NO_COLORS': 'no_colors',
-               'THEFUCK_PRIORITY': 'priority',
-               'THEFUCK_DEBUG': 'debug'}
-
-SETTINGS_HEADER = u"""# The Fuck settings file
-#
-# The rules are defined as in the example bellow:
-#
-# rules = ['cd_parent', 'git_push', 'python_command', 'sudo']
-#
-# The default values are as follows. Uncomment and change to fit your needs.
-# See https://github.com/nvbn/thefuck#settings for more information.
-#
-
-"""
+from . import const
+from .system import Path
 
 
 class Settings(dict):
@@ -46,7 +14,7 @@ class Settings(dict):
     def __setattr__(self, key, value):
         self[key] = value
 
-    def init(self):
+    def init(self, args=None):
         """Fills `settings` with values from `settings.py` and env."""
         from .logs import exception
 
@@ -63,24 +31,29 @@ class Settings(dict):
         except Exception:
             exception("Can't load settings from env", sys.exc_info())
 
+        self.update(self._settings_from_args(args))
+
     def _init_settings_file(self):
         settings_path = self.user_dir.joinpath('settings.py')
         if not settings_path.is_file():
             with settings_path.open(mode='w') as settings_file:
-                settings_file.write(SETTINGS_HEADER)
-                for setting in DEFAULT_SETTINGS.items():
+                settings_file.write(const.SETTINGS_HEADER)
+                for setting in const.DEFAULT_SETTINGS.items():
                     settings_file.write(u'# {} = {}\n'.format(*setting))
 
     def _get_user_dir_path(self):
-        # for backward compatibility, use `~/.thefuck` if it exists
-        legacy_user_dir = Path(os.path.expanduser('~/.thefuck'))
+        """Returns Path object representing the user config resource"""
+        xdg_config_home = os.environ.get('XDG_CONFIG_HOME', '~/.config')
+        user_dir = Path(xdg_config_home, 'thefuck').expanduser()
+        legacy_user_dir = Path('~', '.thefuck').expanduser()
 
+        # For backward compatibility use legacy '~/.thefuck' if it exists:
         if legacy_user_dir.is_dir():
+            warn(u'Config path {} is deprecated. Please move to {}'.format(
+                legacy_user_dir, user_dir))
             return legacy_user_dir
         else:
-            default_xdg_config_dir = os.path.expanduser("~/.config")
-            xdg_config_dir = os.getenv("XDG_CONFIG_HOME", default_xdg_config_dir)
-            return Path(os.path.join(xdg_config_dir, 'thefuck'))
+            return user_dir
 
     def _setup_user_dir(self):
         """Returns user config dir, create it when it doesn't exist."""
@@ -96,14 +69,14 @@ class Settings(dict):
         settings = load_source(
             'settings', text_type(self.user_dir.joinpath('settings.py')))
         return {key: getattr(settings, key)
-                for key in DEFAULT_SETTINGS.keys()
+                for key in const.DEFAULT_SETTINGS.keys()
                 if hasattr(settings, key)}
 
     def _rules_from_env(self, val):
         """Transforms rules list from env-string to python."""
         val = val.split(':')
         if 'DEFAULT_RULES' in val:
-            val = DEFAULT_RULES + [rule for rule in val if rule != 'DEFAULT_RULES']
+            val = const.DEFAULT_RULES + [rule for rule in val if rule != 'DEFAULT_RULES']
         return val
 
     def _priority_from_env(self, val):
@@ -122,18 +95,36 @@ class Settings(dict):
             return self._rules_from_env(val)
         elif attr == 'priority':
             return dict(self._priority_from_env(val))
-        elif attr == 'wait_command':
+        elif attr in ('wait_command', 'history_limit', 'wait_slow_command',
+                      'num_close_matches'):
             return int(val)
-        elif attr in ('require_confirmation', 'no_colors', 'debug'):
+        elif attr in ('require_confirmation', 'no_colors', 'debug',
+                      'alter_history', 'instant_mode'):
             return val.lower() == 'true'
+        elif attr in ('slow_commands', 'excluded_search_path_prefixes'):
+            return val.split(':')
         else:
             return val
 
     def _settings_from_env(self):
         """Loads settings from env."""
         return {attr: self._val_from_env(env, attr)
-                for env, attr in ENV_TO_ATTR.items()
+                for env, attr in const.ENV_TO_ATTR.items()
                 if env in os.environ}
 
+    def _settings_from_args(self, args):
+        """Loads settings from args."""
+        if not args:
+            return {}
 
-settings = Settings(DEFAULT_SETTINGS)
+        from_args = {}
+        if args.yes:
+            from_args['require_confirmation'] = not args.yes
+        if args.debug:
+            from_args['debug'] = args.debug
+        if args.repeat:
+            from_args['repeat'] = args.repeat
+        return from_args
+
+
+settings = Settings(const.DEFAULT_SETTINGS)
