@@ -4,13 +4,12 @@ from thefuck.specific.git import git_support
 
 @git_support
 def match(command):
-    return ('pull' in command.script
-            and 'set-upstream' in command.stderr)
+    return 'pull' in command.script and 'set-upstream' in command.output
 
 
 @git_support
 def get_new_command(command):
-    line = command.stderr.split('\n')[-3].strip()
+    line = command.output.split('\n')[-3].strip()
     branch = line.split(' ')[-1]
     set_upstream = line.replace('<remote>', 'origin')\
                        .replace('<branch>', branch)
